@@ -48,7 +48,7 @@ func (pr *VulnerabilityProvider) GetByDistro(d *distro.Distro, p pkg.Package) ([
 	namespaces := pr.namespaceIndex.NamespacesForDistro(d)
 
 	if len(namespaces) == 0 {
-		log.Warnf("no vulnerability namespaces found for distro=%s", d.String())
+		log.Debugf("no vulnerability namespaces found in grype database for distro=%s package=%s", d.String(), p.Name)
 		return vulnerabilities, nil
 	}
 
@@ -82,7 +82,7 @@ func (pr *VulnerabilityProvider) GetByLanguage(l syftPkg.Language, p pkg.Package
 	namespaces := pr.namespaceIndex.NamespacesForLanguage(l)
 
 	if len(namespaces) == 0 {
-		log.Warnf("no vulnerability namespaces found for language=%s", l)
+		log.Debugf("no vulnerability namespaces found in grype database for language=%s package=%s", l, p.Name)
 		return vulnerabilities, nil
 	}
 
@@ -116,7 +116,7 @@ func (pr *VulnerabilityProvider) GetByCPE(requestCPE syftPkg.CPE) ([]vulnerabili
 	namespaces := pr.namespaceIndex.CPENamespaces()
 
 	if len(namespaces) == 0 {
-		log.Warn("no vulnerability namespaces found for arbitrary CPEs")
+		log.Debugf("no vulnerability namespaces found for arbitrary CPEs in grype database")
 		return nil, nil
 	}
 
