@@ -10,6 +10,7 @@ import (
 
 	"github.com/anchore/grype/grype/distro"
 	"github.com/anchore/grype/grype/pkg"
+	"github.com/anchore/grype/grype/pkg/qualifier"
 	"github.com/anchore/grype/grype/version"
 	"github.com/anchore/grype/grype/vulnerability"
 	syftPkg "github.com/anchore/syft/syft/pkg"
@@ -36,18 +37,20 @@ func TestGetByDistro(t *testing.T) {
 
 	expected := []vulnerability.Vulnerability{
 		{
-			Constraint: version.MustGetConstraint("< 2014.1.3-6", version.DebFormat),
-			ID:         "CVE-2014-fake-1",
-			Namespace:  "debian:distro:debian:8",
-			CPEs:       []syftPkg.CPE{},
-			Advisories: []vulnerability.Advisory{},
+			Constraint:        version.MustGetConstraint("< 2014.1.3-6", version.DebFormat),
+			ID:                "CVE-2014-fake-1",
+			Namespace:         "debian:distro:debian:8",
+			PackageQualifiers: []qualifier.Qualifier{},
+			CPEs:              []syftPkg.CPE{},
+			Advisories:        []vulnerability.Advisory{},
 		},
 		{
-			Constraint: version.MustGetConstraint("< 2013.0.2-1", version.DebFormat),
-			ID:         "CVE-2013-fake-2",
-			Namespace:  "debian:distro:debian:8",
-			CPEs:       []syftPkg.CPE{},
-			Advisories: []vulnerability.Advisory{},
+			Constraint:        version.MustGetConstraint("< 2013.0.2-1", version.DebFormat),
+			ID:                "CVE-2013-fake-2",
+			Namespace:         "debian:distro:debian:8",
+			PackageQualifiers: []qualifier.Qualifier{},
+			CPEs:              []syftPkg.CPE{},
+			Advisories:        []vulnerability.Advisory{},
 		},
 	}
 
@@ -100,8 +103,9 @@ func TestGetByCPE(t *testing.T) {
 					CPEs: []syftPkg.CPE{
 						must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:*:*:something:*:*:ruby:*:*")),
 					},
-					Namespace:  "nvd:cpe",
-					Advisories: []vulnerability.Advisory{},
+					Namespace:         "nvd:cpe",
+					PackageQualifiers: []qualifier.Qualifier{},
+					Advisories:        []vulnerability.Advisory{},
 				},
 			},
 		},
@@ -115,8 +119,9 @@ func TestGetByCPE(t *testing.T) {
 					CPEs: []syftPkg.CPE{
 						must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:*:*:something:*:*:ruby:*:*")),
 					},
-					Namespace:  "nvd:cpe",
-					Advisories: []vulnerability.Advisory{},
+					Namespace:         "nvd:cpe",
+					PackageQualifiers: []qualifier.Qualifier{},
+					Advisories:        []vulnerability.Advisory{},
 				},
 			},
 		},
@@ -130,8 +135,9 @@ func TestGetByCPE(t *testing.T) {
 					CPEs: []syftPkg.CPE{
 						must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*")),
 					},
-					Namespace:  "nvd:cpe",
-					Advisories: []vulnerability.Advisory{},
+					Namespace:         "nvd:cpe",
+					PackageQualifiers: []qualifier.Qualifier{},
+					Advisories:        []vulnerability.Advisory{},
 				},
 				{
 					Constraint: version.MustGetConstraint("< 3.7.4", version.UnknownFormat),
@@ -139,8 +145,9 @@ func TestGetByCPE(t *testing.T) {
 					CPEs: []syftPkg.CPE{
 						must(syftPkg.NewCPE("cpe:2.3:*:activerecord:activerecord:*:*:something:*:*:ruby:*:*")),
 					},
-					Namespace:  "nvd:cpe",
-					Advisories: []vulnerability.Advisory{},
+					Namespace:         "nvd:cpe",
+					PackageQualifiers: []qualifier.Qualifier{},
+					Advisories:        []vulnerability.Advisory{},
 				},
 			},
 		},
