@@ -7,6 +7,7 @@ import (
 
 	"github.com/go-test/deep"
 	"github.com/sergi/go-diff/diffmatchpatch"
+	"github.com/stretchr/testify/assert"
 
 	"github.com/anchore/go-testutils"
 	"github.com/anchore/grype/grype/match"
@@ -18,69 +19,103 @@ import (
 
 var update = flag.Bool("update", false, "update the *.golden files for table presenters")
 
+var pkg1 = pkg.Package{
+	ID:      "package-1-id",
+	Name:    "package-1",
+	Version: "1.0.1",
+	Type:    syftPkg.DebPkg,
+}
+
+var pkg2 = pkg.Package{
+	ID:      "package-2-id",
+	Name:    "package-2",
+	Version: "2.0.1",
+	Type:    syftPkg.DebPkg,
+}
+
+var match1 = match.Match{
+
+	Vulnerability: vulnerability.Vulnerability{
+		ID:        "CVE-1999-0001",
+		Namespace: "source-1",
+	},
+	Package: pkg1,
+	Details: []match.Detail{
+		{
+			Type:    match.ExactDirectMatch,
+			Matcher: match.DpkgMatcher,
+		},
+	},
+}
+
+var match2 = match.Match{
+
+	Vulnerability: vulnerability.Vulnerability{
+		ID:        "CVE-1999-0002",
+		Namespace: "source-2",
+		Fix: vulnerability.Fix{
+			Versions: []string{
+				"the-next-version",
+			},
+		},
+	},
+	Package: pkg2,
+	Details: []match.Detail{
+		{
+			Type:    match.ExactIndirectMatch,
+			Matcher: match.DpkgMatcher,
+			SearchedBy: map[string]interface{}{
+				"some": "key",
+			},
+		},
+	},
+}
+
+func TestCreateRow(t *testing.T) {
+	cases := []struct {
+		name           string
+		match          match.Match
+		severitySuffix string
+		expectedErr    error
+		expectedRow    []string
+	}{
+		{
+			name:           "create row for vulnerability",
+			match:          match1,
+			severitySuffix: "",
+			expectedErr:    nil,
+			expectedRow:    []string{match1.Package.Name, match1.Package.Version, "", string(match1.Package.Type), match1.Vulnerability.ID, "Low"},
+		},
+		{
+			name:           "create row for suppressed vulnerability",
+			match:          match1,
+			severitySuffix: appendSuppressed,
+			expectedErr:    nil,
+			expectedRow:    []string{match1.Package.Name, match1.Package.Version, "", string(match1.Package.Type), match1.Vulnerability.ID, "Low (suppressed)"},
+		},
+	}
+
+	for _, testCase := range cases {
+		t.Run(testCase.name, func(t *testing.T) {
+			row, err := createRow(testCase.match, models.NewMetadataMock(), testCase.severitySuffix)
+
+			assert.Equal(t, testCase.expectedErr, err)
+			assert.Equal(t, testCase.expectedRow, row)
+		})
+	}
+}
+
 func TestTablePresenter(t *testing.T) {
 
 	var buffer bytes.Buffer
 
-	var pkg1 = pkg.Package{
-		ID:      "package-1-id",
-		Name:    "package-1",
-		Version: "1.0.1",
-		Type:    syftPkg.DebPkg,
-	}
-
-	var pkg2 = pkg.Package{
-		ID:      "package-2-id",
-		Name:    "package-2",
-		Version: "2.0.1",
-		Type:    syftPkg.DebPkg,
-	}
-
-	var match1 = match.Match{
-
-		Vulnerability: vulnerability.Vulnerability{
-			ID:        "CVE-1999-0001",
-			Namespace: "source-1",
-		},
-		Package: pkg1,
-		Details: []match.Detail{
-			{
-				Type:    match.ExactDirectMatch,
-				Matcher: match.DpkgMatcher,
-			},
-		},
-	}
-
-	var match2 = match.Match{
-
-		Vulnerability: vulnerability.Vulnerability{
-			ID:        "CVE-1999-0002",
-			Namespace: "source-2",
-			Fix: vulnerability.Fix{
-				Versions: []string{
-					"the-next-version",
-				},
-			},
-		},
-		Package: pkg2,
-		Details: []match.Detail{
-			{
-				Type:    match.ExactIndirectMatch,
-				Matcher: match.DpkgMatcher,
-				SearchedBy: map[string]interface{}{
-					"some": "key",
-				},
-			},
-		},
-	}
-
 	matches := match.NewMatches()
 
 	matches.Add(match1, match2)
 
 	packages := []pkg.Package{pkg1, pkg2}
 
-	pres := NewPresenter(matches, packages, models.NewMetadataMock())
+	pres := NewPresenter(matches, packages, models.NewMetadataMock(), []match.IgnoredMatch{})
 
 	// TODO: add a constructor for a match.Match when the data is better shaped
 
@@ -113,7 +148,7 @@ func TestEmptyTablePresenter(t *testing.T) {
 
 	matches := match.NewMatches()
 
-	pres := NewPresenter(matches, []pkg.Package{}, models.NewMetadataMock())
+	pres := NewPresenter(matches, []pkg.Package{}, models.NewMetadataMock(), []match.IgnoredMatch{})
 
 	// run presenter
 	err := pres.Present(&buffer)
