@@ -3,7 +3,8 @@ package vulnerability
 import (
 	"fmt"
 
-	grypeDB "github.com/anchore/grype/grype/db/v4"
+	grypeDB "github.com/anchore/grype/grype/db/v5"
+	"github.com/anchore/grype/grype/pkg/qualifier"
 	"github.com/anchore/grype/grype/version"
 	"github.com/anchore/syft/syft/pkg"
 )
@@ -15,6 +16,7 @@ type Reference struct {
 
 type Vulnerability struct {
 	Constraint             version.Constraint
+	PackageQualifiers      []qualifier.Qualifier
 	CPEs                   []pkg.CPE
 	ID                     string
 	Namespace              string
@@ -31,6 +33,11 @@ func NewVulnerability(vuln grypeDB.Vulnerability) (*Vulnerability, error) {
 		return nil, fmt.Errorf("failed to parse constraint='%s' format='%s': %w", vuln.VersionConstraint, format, err)
 	}
 
+	pkgQualifiers := make([]qualifier.Qualifier, len(vuln.PackageQualifiers))
+	for idx, q := range vuln.PackageQualifiers {
+		pkgQualifiers[idx] = q.Parse()
+	}
+
 	advisories := make([]Advisory, len(vuln.Advisories))
 	for idx, advisory := range vuln.Advisories {
 		advisories[idx] = Advisory{
@@ -48,10 +55,11 @@ func NewVulnerability(vuln grypeDB.Vulnerability) (*Vulnerability, error) {
 	}
 
 	return &Vulnerability{
-		Constraint: constraint,
-		ID:         vuln.ID,
-		CPEs:       make([]pkg.CPE, 0),
-		Namespace:  vuln.Namespace,
+		Constraint:        constraint,
+		ID:                vuln.ID,
+		CPEs:              make([]pkg.CPE, 0),
+		Namespace:         vuln.Namespace,
+		PackageQualifiers: pkgQualifiers,
 		Fix: Fix{
 			Versions: vuln.Fix.Versions,
 			State:    vuln.Fix.State,
@@ -62,9 +70,9 @@ func NewVulnerability(vuln grypeDB.Vulnerability) (*Vulnerability, error) {
 }
 
 func (v Vulnerability) String() string {
-	return fmt.Sprintf("Vuln(id=%s constraint=%q)", v.ID, v.Constraint.String())
+	return fmt.Sprintf("Vuln(id=%s constraint=%q qualifiers=%+v)", v.ID, v.Constraint.String(), v.PackageQualifiers)
 }
 
 func (v *Vulnerability) hash() string {
-	return fmt.Sprintf("%s|%s|%+v", v.ID, v.Constraint, v.CPEs)
+	return fmt.Sprintf("%s|%s|%+v|%+v", v.ID, v.Constraint, v.PackageQualifiers, v.CPEs)
 }
